Crate nostd_printf

Crate nostd_printf 

nostd-printf

Rust crate containing an embedded version of printf which can be used in no_std projects which aren’t linked to libc.

Structs

__va_list_tag

Functions

fctprintf⚠
printf with output function You may use this as dynamic alternative to printf() with its fixed _putchar() output \param out An output function which takes one character and an argument pointer \param arg An argument pointer for user data passed to output function \param format A string that specifies the format of the output \return The number of characters that are sent to the output function, not counting the terminating null character
printf⚠
Tiny printf implementation You have to implement putchar if you use printf() To avoid conflicts with the regular printf() API it is overridden by macro defines and internal underscore-appended functions like printf() are used \param format A string that specifies the format of the output \return The number of characters that are written into the array, not counting the terminating null character
set_putchar⚠
snprintf⚠
Tiny snprintf/vsnprintf implementation \param buffer A pointer to the buffer where to store the formatted string \param count The maximum number of characters to store in the buffer, including a terminating null character \param format A string that specifies the format of the output \param va A value identifying a variable arguments list \return The number of characters that COULD have been written into the buffer, not counting the terminating null character. A value equal or larger than count indicates truncation. Only when the returned value is non-negative and less than count, the string has been completely written.
sprintf⚠
Tiny sprintf implementation Due to security reasons (buffer overflow) YOU SHOULD CONSIDER USING (V)SNPRINTF INSTEAD! \param buffer A pointer to the buffer where to store the formatted string. MUST be big enough to store the output! \param format A string that specifies the format of the output \return The number of characters that are WRITTEN into the buffer, not counting the terminating null character
vprintf⚠
Tiny vprintf implementation \param format A string that specifies the format of the output \param va A value identifying a variable arguments list \return The number of characters that are WRITTEN into the buffer, not counting the terminating null character
vsnprintf⚠

Type Aliases

__builtin_va_list
__gnuc_va_list
putchar
Function pointer for a function to output a character to a custom device like UART \param character Character to output
va_list
wchar_t