Function fctprintf

pub unsafe extern "C" fn fctprintf(
    out: Option<unsafe extern "C" fn(character: c_char, arg: *mut c_void)>,
    arg: *mut c_void,
    format: *const c_char,
    ...
) -> c_int
printf with output function You may use this as dynamic alternative to printf() with its fixed _putchar() output \param out An output function which takes one character and an argument pointer \param arg An argument pointer for user data passed to output function \param format A string that specifies the format of the output \return The number of characters that are sent to the output function, not counting the terminating null character