Function printf

pub unsafe extern "C" fn printf(format: *const c_char, ...) -> c_int
Tiny printf implementation You have to implement putchar if you use printf() To avoid conflicts with the regular printf() API it is overridden by macro defines and internal underscore-appended functions like printf() are used \param format A string that specifies the format of the output \return The number of characters that are written into the array, not counting the terminating null character