pub unsafe extern "C" fn snprintf(
buffer: *mut c_char,
count: c_uint,
format: *const c_char,
...
) -> c_intExpand description
Tiny snprintf/vsnprintf implementation \param buffer A pointer to the buffer where to store the formatted string \param count The maximum number of characters to store in the buffer, including a terminating null character \param format A string that specifies the format of the output \param va A value identifying a variable arguments list \return The number of characters that COULD have been written into the buffer, not counting the terminating null character. A value equal or larger than count indicates truncation. Only when the returned value is non-negative and less than count, the string has been completely written.