Function vprintf

pub unsafe extern "C" fn vprintf(
    format: *const c_char,
    va: __builtin_va_list,
) -> c_int
Tiny vprintf implementation \param format A string that specifies the format of the output \param va A value identifying a variable arguments list \return The number of characters that are WRITTEN into the buffer, not counting the terminating null character