pub unsafe extern "C" fn sprintf(
buffer: *mut c_char,
format: *const c_char,
...
) -> c_intExpand description
Tiny sprintf implementation Due to security reasons (buffer overflow) YOU SHOULD CONSIDER USING (V)SNPRINTF INSTEAD! \param buffer A pointer to the buffer where to store the formatted string. MUST be big enough to store the output! \param format A string that specifies the format of the output \return The number of characters that are WRITTEN into the buffer, not counting the terminating null character